==> nextcloud-26.0.10.tgz: nextcloud/apps/updatenotification/l10n/zh_CN.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "新版本 {version} 已可以使用。获取更多升级相关信息。",
    "Channel updated" : "更新通道",
    "Web updater is disabled" : "已禁用 web 更新器",
    "Update notifications" : "升级通知",
    "The update server could not be reached since %d days to check for new updates." : "更新服务器自 %d 天前起无法访问以检查更新。",
    "Please check the Nextcloud and server log files for errors." : "请检查 Nextcloud 和服务器的日志中的错误。",
    "Update to %1$s is available." : " 可以更新到 %1$s 。",
    "Update to {serverAndVersion} is available." : "可以更新到 {serverAndVersion} 。",
    "Update for {app} to version %s is available." : "可以将您的 {app} 更新到版本 %s 。",
    "Update notification" : "更新通知",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "显示 Nextcloud 的更新提示，并提供更新器的认证页面。",
    "Update" : "更新",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "您运行的版本已经不再被维护了。请尽快更新到一个受支持的版本。",
    "Apps missing compatible version" : "缺少兼容版本的应用",
    "View in store" : "在商店中查看",
    "Apps with compatible version" : "有兼容版本的应用",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "注意：不推荐超过100个用户的站点使用网页更新程序！请改用命令行更新！",
    "Open updater" : "打开更新器",
    "Download now" : "开始下载",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "网页更新程序已禁用。请使用命令行更新器或者其他更新机制（例如 Docker 拉取）进行更新。",
    "What's new?" : "有哪些更新？",
    "View changelog" : "查看更新记录",
    "The update check is not yet finished. Please refresh the page." : "更新检查未完成。请刷新页面。",
    "Your version is up to date." : "您的版本已是最新。",
    "A non-default update server is in use to be checked for updates:" : "检查更新使用了一个非默认的服务器：",
    "Update channel" : "更新通道",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "更改更新通道会同样影响应用管理页面。比如在切换到测试通道后，在应用管理页面中也会提供测试版的应用更新。",
    "Current update channel:" : "当前的更新通道：",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "您可以升级到新版本，但不能降级到更稳定的旧版本。",
    "Notify members of the following groups about available updates:" : "提醒以下组群的用户关于可用的更新：",
    "No groups" : "无群组",
    "Only notifications for app updates are available." : "只有应用更新的通知可用",
    "The selected update channel makes dedicated notifications for the server obsolete." : "被选中的升级通道将会通知未更新的服务器。",
    "The selected update channel does not support updates of the server." : "选中的更新通道不支持服务器升级。",
    "A new version is available: <strong>{newVersionString}</strong>" : "有可用的新版本： <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "注意，在新版本发布之后，更新只在第一个次要版本或更高版本之后出现。随着时间的推移，我们会向用户推出新的版本，有时会在发现问题时跳过某个版本。要了解关于更新和发布通道的更多信息，点击 {link}。",
    "Checked on {lastCheckedDate}" : "检查时间 {lastCheckedDate}",
    "Checking apps for compatible versions" : "正在检查应用程序的兼容版本",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "请确认 config.php 没有设置<samp>appstoreenabled </samp> 为 false。",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "无法连接到应用商店或没有返回任何更新。手动搜索更新，或者确保你的服务器可以上网且可以连接到应用商店。",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>所有</strong>应用都有与这个 Nextcloud 版本兼容的版本可用",
    "Enterprise" : "企业级",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "供企业使用。总是提供最新的补丁级别，但不会马上升级到下一个大版本。当Nextcloud GmbH为大规模和关键任务部署完成额外的加固和测试后，升级才会进行。此频道只对客户可用，提供Nextcloud企业级软件包。",
    "Stable" : "稳定版",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "最新稳定版本。适合日常使用并总是更新至最新主版本。",
    "Beta" : "Beta 测试版",
    "A pre-release version only for testing new features, not for production environments." : "预发布版本仅作测试新功能用，不可用于生产环境。",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong>个应用没有与这个 Nextcloud 版本兼容的版本可用"],
    "Please use the command line updater to update." : "请使用命令行更新器来更新",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "你可以在下面改变更新渠道，这也会影响到应用管理页面。例如：切换到测试版渠道后，测试版应用程序的更新将在应用程序管理页面提供给你。",
    "Update channel:" : "更新通道："
},
"nplurals=1; plural=0;");

==> nextcloud-27.1.7p0.tgz: nextcloud/apps/updatenotification/l10n/zh_CN.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "新版本 {version} 已可以使用。获取更多升级相关信息。",
    "Channel updated" : "更新通道",
    "Web updater is disabled" : "已禁用 web 更新器",
    "Update notifications" : "升级通知",
    "The update server could not be reached since %d days to check for new updates." : "更新服务器自 %d 天前起无法访问以检查更新。",
    "Please check the Nextcloud and server log files for errors." : "请检查 Nextcloud 和服务器的日志中的错误。",
    "Update to %1$s is available." : " 可以更新到 %1$s 。",
    "Update to {serverAndVersion} is available." : "可以更新到 {serverAndVersion} 。",
    "Update for {app} to version %s is available." : "可以将您的 {app} 更新到版本 %s 。",
    "Update notification" : "更新通知",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "显示 Nextcloud 的更新提示，并提供更新器的认证页面。",
    "Update" : "更新",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "您运行的版本已经不再被维护了。请尽快更新到一个受支持的版本。",
    "Apps missing compatible version" : "缺少兼容版本的应用",
    "View in store" : "在商店中查看",
    "Apps with compatible version" : "有兼容版本的应用",
    "Open updater" : "打开更新器",
    "Download now" : "开始下载",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "网页更新程序已禁用。请使用命令行更新器或者其他更新机制（例如 Docker 拉取）进行更新。",
    "What's new?" : "有哪些更新？",
    "View changelog" : "查看更新记录",
    "The update check is not yet finished. Please refresh the page." : "更新检查未完成。请刷新页面。",
    "Your version is up to date." : "您的版本已是最新。",
    "A non-default update server is in use to be checked for updates:" : "检查更新使用了一个非默认的服务器：",
    "Update channel" : "更新通道",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "更改更新通道会同样影响应用管理页面。比如在切换到测试通道后，在应用管理页面中也会提供测试版的应用更新。",
    "Current update channel:" : "当前的更新通道：",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "您可以升级到新版本，但不能降级到更稳定的旧版本。",
    "Notify members of the following groups about available updates:" : "提醒以下组群的用户关于可用的更新：",
    "No groups" : "无群组",
    "Only notifications for app updates are available." : "只有应用更新的通知可用",
    "The selected update channel makes dedicated notifications for the server obsolete." : "被选中的升级通道将会通知未更新的服务器。",
    "The selected update channel does not support updates of the server." : "选中的更新通道不支持服务器升级。",
    "A new version is available: <strong>{newVersionString}</strong>" : "有可用的新版本： <strong>{newVersionString}</strong>",
    "Checking apps for compatible versions" : "正在检查应用程序的兼容版本",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "请确认 config.php 没有设置<samp>appstoreenabled </samp> 为 false。",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "无法连接到应用商店或没有返回任何更新。手动搜索更新，或者确保你的服务器可以上网且可以连接到应用商店。",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>所有</strong>应用都有与这个 Nextcloud 版本兼容的版本可用",
    "Enterprise" : "企业级",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "供企业使用。总是提供最新的补丁级别，但不会马上升级到下一个大版本。当Nextcloud GmbH为大规模和关键任务部署完成额外的加固和测试后，升级才会进行。此频道只对客户可用，提供Nextcloud企业级软件包。",
    "Stable" : "稳定版",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "最新稳定版本。适合日常使用并总是更新至最新主版本。",
    "Beta" : "Beta 测试版",
    "A pre-release version only for testing new features, not for production environments." : "预发布版本仅作测试新功能用，不可用于生产环境。",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong>个应用没有与这个 Nextcloud 版本兼容的版本可用"],
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "注意：不推荐超过100个用户的站点使用网页更新程序！请改用命令行更新！",
    "Please use the command line updater to update." : "请使用命令行更新器来更新",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "你可以在下面改变更新渠道，这也会影响到应用管理页面。例如：切换到测试版渠道后，测试版应用程序的更新将在应用程序管理页面提供给你。",
    "Update channel:" : "更新通道：",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "注意，在新版本发布之后，更新只在第一个次要版本或更高版本之后出现。随着时间的推移，我们会向用户推出新的版本，有时会在发现问题时跳过某个版本。要了解关于更新和发布通道的更多信息，点击 {link}。",
    "Checked on {lastCheckedDate}" : "检查时间 {lastCheckedDate}"
},
"nplurals=1; plural=0;");
